Error

Enum Error 

pub enum Error {
    RegexSyntax(Error),
    UnsupportedRegex(&'static str),
}
Errors which may occur when preparing a regular expression for use with string generation.

Variants



RegexSyntax(Error)

The string passed as the regex was not syntactically valid.



UnsupportedRegex(&'static str)

The regex was syntactically valid, but contains elements not supported by proptest.